@@ -254,11 +254,11 @@ class CloudFrontToS3Props:
         :summary: The properties for the CloudFrontToS3 Construct
         '''
         if isinstance(bucket_props, dict):
-            bucket_props = BucketProps(**bucket_props)
+            bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(cloud_front_logging_bucket_props, dict):
-            cloud_front_logging_bucket_props = BucketProps(**cloud_front_logging_bucket_props)
+            cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
         if isinstance(logging_bucket_props, dict):
-            logging_bucket_props = BucketProps(**logging_bucket_props)
+            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if __debug__:
             type_hints = typing.get_type_hints(CloudFrontToS3Props.__init__)
             check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
